/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.service;

import static org.fortiss.tooling.kernel.ui.ToolingKernelUIActivator.getService;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.ToolingKernelActivator;
import org.fortiss.tooling.kernel.ui.extension.IModelEditor;
import org.fortiss.tooling.kernel.ui.extension.IModelEditorBinding;
import org.fortiss.tooling.kernel.utils.ServicesUtils;

/**
 * The model editor service handles editor registration. It also allows opening
 * and closing of editors.
 * 
 * @see IModelEditorBinding
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: DB0D8B5DE0054841E373D7306A108434
 */
public interface IModelEditorBindingService {
	/**
	 * Returns the service instance.
	 * 
	 * @deprecated use {@link ServicesUtils#getService(org.osgi.framework.Bundle, Class)} and
	 *             {@link ServicesUtils#ungetService(org.osgi.framework.Bundle, Class)}, instead.
	 *             See also {@link ToolingKernelActivator#getService(Class)} and
	 *             {@link ToolingKernelActivator#ungetService(Class)}
	 */
	@Deprecated
	public static IModelEditorBindingService getInstance() {
		return getService(IModelEditorBindingService.class);
	}

	/** Opens an editor for the given element. */
	void openInEditor(EObject element);

	/** Closes editors which depend on the given element or a sub-element. */
	void closeEditors(EObject parentElement);

	/** Closes all editors. */
	void closeAllEditors();

	/** Closes editor of the given element. */
	void closeEditor(EObject element);

	/** Check whether editor of the given element is opened. */
	boolean isOpen(EObject element);

	/** Returns the currently active editor. */
	IModelEditor<EObject> getActiveEditor();

	/** Returns registered editor bindings for the given {@link EObject}. */
	List<IModelEditorBinding<EObject>> getBindings(EObject element);
}
